Class: Users::SessionsController
- Inherits:
-
Devise::SessionsController
- Object
- Devise::SessionsController
- Users::SessionsController
- Defined in:
- lib/generators/llm_meta_client/authentication/templates/app/controllers/users/sessions_controller.rb
Instance Method Summary collapse
-
#destroy ⇒ Object
Delete web application session and redirect to sign out action.
Instance Method Details
#destroy ⇒ Object
Delete web application session and redirect to sign out action
3 4 5 6 7 8 9 10 11 12 |
# File 'lib/generators/llm_meta_client/authentication/templates/app/controllers/users/sessions_controller.rb', line 3 def destroy # Delete session if current_user sign_out current_user reset_session end flash[:notice] = "You have successfully signed out." redirect_to root_path end |